@@ -2,30 +2,29 @@
 
 import os
 import sys
-sys.path.insert(0, os.path.abspath('../../subpop'))
+
+sys.path.insert(0, os.path.abspath("../../subpop"))
 
 
 # -- Project information -----------------------------------------------------
 
-project = 'subpop'
-copyright = '2021, VMware, Inc.'
-author = 'Daniel Robbins'
-html_context = {
-    "project_url" : "https://projects.funtoo.org/subpop"
-}
+project = "subpop"
+copyright = "2021, Daniel Robbins"
+author = "Daniel Robbins"
+html_context = {"project_url": "https://projects.funtoo.org/subpop"}
 # The full version, including alpha/beta/rc tags
-release = '0.1'
+release = "0.1"
 
 # -- General configuration ---------------------------------------------------
 
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 
 # -- Options for HTML output -------------------------------------------------
@@ -37,17 +36,13 @@ exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = ["_static"]
 
-master_doc = 'index'
+master_doc = "index"
 
 
 import sphinx_funtoo_theme
 
-extensions = [
-    "sphinx_funtoo_theme",
-    'sphinx.ext.autosectionlabel',
-    'sphinx.ext.autodoc'
-]
+extensions = ["sphinx_funtoo_theme", "sphinx.ext.autosectionlabel", "sphinx.ext.autodoc"]
 
 html_theme = "sphinx_funtoo_theme"
